@@ -16,7 +16,7 @@ use SHARYANTO::Package::Util qw(package_exists);
 use Tie::Cache;
 use URI::Split qw(uri_split uri_join);
 
-our $VERSION = '0.56'; # VERSION
+our $VERSION = '0.57'; # VERSION
 
 our $re_perl_package =
     qr/\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_][A-Za-z_0-9]*)*\z/;
@@ -206,8 +206,15 @@ sub _load_module {
 
     my $pkg = $req->{-perl_package};
 
-    # there is no module to load, or we are instructed not to load any modules.
-    return if !$pkg || !$self->{load};
+    # skip there is no module to load
+    return if !$pkg;
+
+    # if we are instructed not to load any module, we just check via existence
+    # of packages
+    unless ($self->{load}) {
+        return if package_exists($pkg);
+        return err(500, "Package $pkg does not exist");
+    }
 
     my $module_p = $pkg;
     $module_p =~ s!::!/!g;
@@ -484,9 +491,6 @@ sub action_list {
         1;
     };
 
-    # TODO: if load=0, then instead of using list_modules(), use list_packages()
-    # instead and skip the filesystem.
-
     my %mem;
 
     # get submodules
@@ -890,7 +894,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 DESCRIPTION
 
